@@ -12,11 +12,11 @@ FFmpeg::Stream::Helper - Helper for streaming and transcoding using ffmpeg.
 
 =head1 VERSION
 
-Version 0.0.2
+Version 0.1.0
 
 =cut
 
-our $VERSION = '0.0.2';
+our $VERSION = '0.1.0';
 
 =head1 SYNOPSIS
 
@@ -101,7 +101,7 @@ sub new{
 		kbps=>2000,
 		loglevel=>'quiet',
 		threads=>'0',
-		format=>'mp4',
+		format=>'webm',
 	};
 	bless $self;
 
@@ -280,17 +280,27 @@ sub command{
 	if ( defined( $self->{bound} ) ){
 		$bound=' -vf scale='.shell_quote($self->{bound}).':-1 ';
 	}
-	
-	# ffmpeg -ss %o -i %s -async 1 -b %bk -s %wx%h -ar 44100 -ac 2 -v 0 -f flv -vcodec libx264 -preset superfast -threads 0 -
-	my $command='ffmpeg -i '.shell_quote($file).
-		' -async 1 -b '.shell_quote($self->{kbps}).'k '.
-		' -ar 44100 -ac 2 -v 0 -f '.shell_quote($self->{format}).
-		' -loglevel '.shell_quote($self->{loglevel}).
-		$bound.
-		' -vcodec libx264 -preset superfast -threads '.shell_quote($self->{threads}).
-		' -g 52 -movflags frag_keyframe+empty_moov'.
-		' '.shell_quote($self->{output});
 
+	my $command='';
+
+	if ( $command eq 'webm' ){
+		$command='ffmpeg -i '.shell_quote($file).
+			' -loglevel '.shell_quote($self->{loglevel}).
+			$bound.
+			'-f webm -c:v libvpx -maxrate '.$self->{kbps}.'k -preset superfast -threads 0'.
+			' '.shell_quote($self->{output});
+	}else{
+		# ffmpeg -ss %o -i %s -async 1 -b %bk -s %wx%h -ar 44100 -ac 2 -v 0 -f flv -vcodec libx264 -preset superfast -threads 0 -
+		$command='ffmpeg -i '.shell_quote($file).
+			' -async 1 -b '.shell_quote($self->{kbps}).'k '.
+			' -ar 44100 -ac 2 -v 0 -f '.shell_quote($self->{format}).
+			' -loglevel '.shell_quote($self->{loglevel}).
+			$bound.
+			' -vcodec libx264 -preset superfast -threads '.shell_quote($self->{threads}).
+			' -g 52 -movflags frag_keyframe+empty_moov'.
+			' '.shell_quote($self->{output});
+
+	}
 	return $command;
 }
 
